@@ -2,7 +2,9 @@ package MojoMojo::Controller::PageAdmin;
 use warnings;
 use strict;
 use parent 'Catalyst::Controller::HTML::FormFu';
-use Syntax::Highlight::Engine::Kate;
+
+eval {require Syntax::Highlight::Engine::Kate};
+my $kate_installed = !$@;
 
 =head1 NAME
 
@@ -52,6 +54,74 @@ sub auto : Private {
     $c->detach('unauthorized', [$c->loc('edit')]);
 }
 
+=head2 delete
+
+Delete a page and it's descendants.
+
+=cut
+
+sub delete : Global FormConfig {
+    my ( $self, $c, $path ) = @_;
+
+    my $form  = $c->stash->{form};
+    my $stash = $c->stash;
+    $stash->{template} = 'page/delete.tt';
+
+    my @descendants;
+    push @descendants, {
+        name       => $_->name_orig,
+        id         => $_->id,
+        can_delete => ($_->id == 1) ? 0 : $c->check_permissions($_->path, $c->user)->{delete},
+    } for sort { $a->{path} cmp $b->{path} } $c->stash->{'page'}->descendants;
+
+    $stash->{descendants}       = \@descendants;
+    $stash->{allowed_to_delete} = ( grep {$_->{can_delete} == 0} @descendants )
+                                ? 0 : 1;
+
+    if ( $form->submitted_and_valid && $stash->{allowed_to_delete} ) {
+        my @deleted_pages;
+        my @ids_to_delete;
+        for my $page ( $c->stash->{'page'}->descendants ) {
+            push @deleted_pages, $page->name_orig;
+            push @ids_to_delete, $page->id;
+
+            # remove page from search index
+            $c->model('Search')->delete_page($page);
+        }
+
+        my @tables = (
+            { module => 'DBIC::PageVersion', column => 'page' },
+            { module => 'DBIC::Attachment', column => 'page' },
+            { module => 'DBIC::Comment', column => 'page' },
+            { module => 'DBIC::Link', column => [ qw(from_page to_page) ] },
+            { module => 'DBIC::RolePrivilege', column => 'page' },
+            { module => 'DBIC::Tag', column => 'page' },
+            { module => 'DBIC::WantedPage', column => 'from_page' },
+            { module => 'DBIC::Journal', column => 'pageid' },
+            { module => 'DBIC::Entry', column => 'journal' },
+            { module => 'DBIC::Content', column => 'page' },
+            { module => 'DBIC::Page', column => 'id' },
+        );
+
+        for my $descendant ( reverse @descendants ) {
+            for my $table ( @tables ) {
+                my $search;
+                if( ref $table->{column} ) {
+                    push @{$search}, { $_ => $descendant->{id} }
+                        for(@{$table->{column}});
+                } else {
+                    $search = { $table->{column} => $descendant->{id} }
+                }
+
+                $c->model( $table->{module} )->search( $search )->delete_all;
+            }
+        }
+
+        $stash->{'deleted_pages'} = \@deleted_pages;
+        $stash->{'template'}      = 'page/deleted.tt';
+    }
+}
+
 =head2 edit
 
 This action will display the edit form, then save the previous
@@ -68,7 +138,7 @@ sub edit : Global FormConfig {
     my $stash = $c->stash;
     $stash->{template} = 'page/edit.tt';
 
-    my $user_id = $c->user_exists ? $c->user->obj->id : 1;    # Anon edit
+    my $user_id = $c->user_exists ? $c->user->obj->id : 1;  # Anon edit
 
     my ( $path_pages, $proto_pages ) = @$stash{qw/ path_pages proto_pages /};
 
@@ -86,19 +156,15 @@ sub edit : Global FormConfig {
         ? $proto_pages->[-1]
         : $path_pages->[-1]
     );
-
-    # this should never happen!
-    $c->detach('/default') unless $page;  # TODO there is no default action, BTW
     @$stash{qw/ path_pages proto_pages /} = ( $path_pages, $proto_pages );
 
     my $perms =
-      $c->check_permissions( $stash->{'path'},
-        ( $c->user_exists ? $c->user->obj : undef ) );
+      $c->check_permissions( $stash->{'path'},  $c->user_exists ? $c->user->obj : undef );
     my $permtocheck = ( @$proto_pages > 0 ? 'create' : 'edit' );
     my $loc_permtocheck = $permtocheck eq 'create'
       ? $c->loc('create')
       : $c->loc('edit');
-      
+
     # TODO this should be caught in the auto action. To reproduce, disable "Edit allowed by default"
     # in Site settings, then go to /.edit
     if ( !$perms->{$permtocheck} ) {
@@ -127,8 +193,11 @@ sub edit : Global FormConfig {
         $form->process;
     }
 
-    my $syntax = new Syntax::Highlight::Engine::Kate;
-    $c->stash->{syntax_formatters} = [ $syntax->languageList() ];
+    # prepare the list of available syntax highlighters
+    if ($kate_installed) {
+        my $syntax = new Syntax::Highlight::Engine::Kate;
+        $c->stash->{syntax_formatters} = [ $syntax->languageList() ];
+    }    
 
     if ( $form->submitted_and_valid ) {
 
@@ -143,26 +212,10 @@ sub edit : Global FormConfig {
                 creator     => $user_id,
             );
             $page = $path_pages->[-1];
+            
 
             # update the pages that wanted the new one
-            foreach my $want_me ($c->model('DBIC::WantedPage')->search( { to_path => $c->stash->{path} } ) ) {
-                my $wantme_page = $want_me->from_page;
 
-                # convert the wanted into links
-                $c->model('DBIC::Link')->create({
-                    from_page => $wantme_page,
-                    to_page   => $page,
-                });
-
-                # clear the precompiled (will be recompiled on view)
-                if ( my $wantme_content = $wantme_page->content ) {
-                    $wantme_content->precompiled(undef);
-                    $wantme_content->update;
-                }
-
-                # ok, she don't want me anymore ;)
-                $want_me->delete();
-            }
         }
 
         $stash->{content} = $page->content;
@@ -193,7 +246,7 @@ sub edit : Global FormConfig {
         # This speeds up MojoMojo page rendering on /.view actions
         my $precompiled_body = $valid->{'body'};
         MojoMojo->call_plugins( 'format_content', \$precompiled_body, $c, $page );
-        
+
         # Make precompiled empty when we have any of: redirect, comment or include
         $valid->{'precompiled'} = $c->stash->{precompile_off} ? '' : $precompiled_body;
 
@@ -204,7 +257,7 @@ sub edit : Global FormConfig {
         $c->model('Search')->index_page($page)
             unless $c->pref('disable_search');
         $page->content->store_links();
-        
+
         # Redirect back to edits or view page mode.
         my $redirect = $c->uri_for( $c->stash->{path} );
         if ( $form->params->{submit} eq $c->localize('Save') ) {
@@ -329,7 +382,7 @@ sub rollback : Global {
         $c->res->status(400);
         $c->detach('unauthorized', [$c->loc('rollback')]);
     }
-    
+
     if ( $c->req->param('rev') ) {
         # TODO this needs to do a proper versioned rollback, via
         # $page->add_version( content_version => $c->req->param('rev')
@@ -342,6 +395,38 @@ sub rollback : Global {
     }
 }
 
+=head2 title ( .info/title )
+
+AJAX method for renaming a page. Creates a new 
+L<PageVersion|MojoMojo::Schema::Result::PageVersion> with the rename,
+so that the renaming itself could in the future be shown in the page
+history.
+
+=cut
+
+sub title : Path('/info/title') {
+    my ( $self, $c ) = @_;
+    my $page = $c->stash->{page};
+    my $user_id = $c->user_exists ? $c->user->obj->id : 1;  # Anon edit
+    
+    if ($c->req->method ne 'POST') {
+        # general error - we want a POST
+        $c->res->status(400);
+        $c->detach('unauthorized', [$c->loc('rename via non-POST method')]);
+    }
+    
+    if ( $c->req->param('update_value') ) {
+        my $page_version_new = $page->add_version(
+            creator => $user_id,
+            name_orig => $c->req->param('update_value'),
+        );
+        $c->res->body( $page_version_new->name_orig );
+    } else {
+        # User attempted to rename the page to ''. Deny that.
+        $c->res->body( $page->name_orig );
+    }    
+    
+}
 =head1 AUTHOR
 
 Marcus Ramberg <mramberg@cpan.org>
