@@ -1,7 +1,13 @@
 package MojoMojo::Formatter::YouTube;
 
-use parent qw/MojoMojo::Formatter/;
-use URI::Fetch;
+use strict;
+use parent 'MojoMojo::Formatter';
+
+eval {require URI::Fetch};
+my $dependencies_installed = !$@;
+sub module_loaded { $dependencies_installed }
+
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -9,21 +15,21 @@ MojoMojo::Formatter::YouTube - Embed YouTube player
 
 =head1 DESCRIPTION
 
-Embed Youtube video player for given video by writing {{youtube <url>}}.
+Embed YouTube video player for given video by writing {{youtube <url>}}.
 
 =head1 METHODS
 
 =head2 format_content_order
 
-Format order can be 1-99. The YouTube formatter runs on 6.
+Format order can be 1-99. The YouTube formatter runs on 10.
 
 =cut
 
-sub format_content_order { 6 }
+sub format_content_order { 10 }
 
 =head2 format_content
 
-calls the formatter. Takes a ref to the content as well as the
+Calls the formatter. Takes a ref to the content as well as the
 context object.
 
 =cut
@@ -52,7 +58,7 @@ sub process {
     my $youtube = $c->loc('YouTube Video');
     my $video_id;
     $line =~ m/$re/;
-    $url = URI->new($1);
+    my $url = URI->new($1);
 
     unless ($url){
         $line =~ s/$re/"$youtube: $url ".$c->loc('is not a valid url')/e;
@@ -69,7 +75,7 @@ sub process {
     if ( ($c->action->reverse eq 'pageadmin/edit') || ($c->action->reverse eq 'jsrpc/render') ){
         $line =~ s!$re!<div style='width: 425px;height: 344px; border: 1px black dotted;'>$youtube<br /><a href="$url">$url</a></div>!;
      } else {
-        $line =~ s!$re!<object width="425" height="344"><param name="movie" value="http://www.youtube.com/v/$video_id&hl=$lang"></param><param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param><embed src="http://www.youtube.com/v/$video_id&hl=$lang" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="425" height="344"></embed></object>!;
+        $line =~ s!$re!<object width="425" height="344"><param name="movie" value="http://www.youtube.com/v/$video_id&amp;hl=$lang"></param><param name="allowFullScreen" value="true"></param><param name="allowscriptaccess" value="always"></param><embed src="http://www.youtube.com/v/$video_id&amp;hl=$lang" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="425" height="344"></embed></object>!;
     }
     return $line;
 }
